package com.mortals.xhx.feign.app;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.app.AppCategoryPdu;
import com.mortals.xhx.common.pdu.app.AppPdu;
import com.mortals.xhx.common.pdu.app.DeviceBlackappPdu;
import com.mortals.xhx.common.pdu.device.DevicePdu;
import com.mortals.xhx.feign.IFeign;
import com.mortals.xhx.feign.device.IDeviceFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 自助终端应用
 */
@FeignClient(name = "base-manager", path = "/base", fallbackFactory = AppFeignFallbackFactory.class)
public interface IAppFeign extends IFeign {
    /**
     * 查看自助终端应用列表
     *
     * @param appPdu
     * @return
     */
    @PostMapping(value = "/app/list")
    Rest<RespData<List<AppPdu>>> list(@RequestBody AppPdu appPdu);

    /**
     * 查看自助终端应用
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/app/info")
    Rest<AppPdu> info(@RequestParam(value = "id") Long id);

    /**
     * 设备应用黑名单
     * @param appPdu
     * @return
     */
    @PostMapping(value = "/device/blackapp/list")
    Rest<RespData<List<DeviceBlackappPdu>>> blackappList(@RequestBody DeviceBlackappPdu appPdu);

    /**
     * 自助终端应用分类
     *
     * @param appPdu
     * @return
     */
    @PostMapping(value = "/app/category/list")
    Rest<RespData<List<AppCategoryPdu>>> categoryList(@RequestBody AppCategoryPdu appPdu);
}

@Slf4j
@Component
class AppFeignFallbackFactory implements FallbackFactory<IAppFeign> {

    @Override
    public IAppFeign create(Throwable throwable) {
        return new IAppFeign(){

            @Override
            public Rest<RespData<List<AppPdu>>> list(AppPdu appPdu) {
                return Rest.fail("暂时无法获取自助终端应用列表，请稍后再试!");
            }

            @Override
            public Rest<AppPdu> info(Long id) {
                return Rest.fail("暂时无法获取自助终端应用，请稍后再试!");
            }

            @Override
            public Rest<RespData<List<DeviceBlackappPdu>>> blackappList(DeviceBlackappPdu appPdu) {
                return Rest.fail("暂时无法获取设备应用黑名单，请稍后再试!");
            }

            @Override
            public Rest<RespData<List<AppCategoryPdu>>> categoryList(AppCategoryPdu appPdu) {
                return Rest.fail("暂时无法获取自助终端应用分类，请稍后再试!");
            }
        };
    }
}