package com.mortals.xhx.feign.device;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.device.DeviceAlarmPdu;
import com.mortals.xhx.common.pdu.device.DevicePdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 设备告警信息
 */
@FeignClient(name = "device-manager", path = "/m", fallbackFactory = DeviceAlarmFeignFallbackFactory.class)
public interface IDeviceAlarmFeign extends IFeign {
    /**
     * 查看设备告警信息列表
     *
     * @param devicePdu
     * @return
     */
    @PostMapping(value = "/device/alarm/info/list")
    Rest<RespData<List<DeviceAlarmPdu>>> list(@RequestBody DeviceAlarmPdu devicePdu);


    /**
     * 查看设备告警信息
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/device/alarm/info")
    Rest<DeviceAlarmPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class DeviceAlarmFeignFallbackFactory implements FallbackFactory<IDeviceAlarmFeign> {

    @Override
    public IDeviceAlarmFeign create(Throwable throwable) {
        return new IDeviceAlarmFeign() {

            @Override
            public Rest<RespData<List<DeviceAlarmPdu>>> list(DeviceAlarmPdu devicePdu) {
                return Rest.fail("暂时无法获取设备告警信息列表，请稍后再试!");
            }

            @Override
            public Rest<DeviceAlarmPdu> info(Long id) {
                return Rest.fail("暂时无法获取设备告警信息，请稍后再试!");
            }
        };
    }
}
