package com.mortals.xhx.feign.device;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.device.DeviceAlarmPdu;
import com.mortals.xhx.common.pdu.device.DeviceModuleUsePdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

/**
 * 设备模块使用频率
 */
@FeignClient(name = "device-manager", path = "/m", fallbackFactory = DeviceModuleUseFeignFallbackFactory.class)
public interface IDeviceModuleUseFeign extends IFeign {
    /**
     * 查看设备模块使用频率
     *
     * @param devicePdu
     * @return
     */
    @PostMapping(value = "/device/module/use/list")
    Rest<RespData<List<DeviceModuleUsePdu>>> list(@RequestBody DeviceModuleUsePdu devicePdu);
}

@Slf4j
@Component
class DeviceModuleUseFeignFallbackFactory implements FallbackFactory<IDeviceModuleUseFeign> {

    @Override
    public IDeviceModuleUseFeign create(Throwable throwable) {
        return new IDeviceModuleUseFeign(){

            @Override
            public Rest<RespData<List<DeviceModuleUsePdu>>> list(DeviceModuleUsePdu devicePdu) {
                return Rest.fail("暂时无法获取设备模块使用频率列表，请稍后再试!");
            }
        };
    }
}
