package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterAcceptPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterAcceptFallbackFactory.class)
public interface IMatterAcceptFeign extends IFeign {
    /**
     * 查看事项受理条件列表
     *
     * @param matterAcceptPdu
     * @return
     */
    @PostMapping(value = "/matter/accept/list")
    Rest<RespData<List<MatterAcceptPdu>>> list(@RequestBody MatterAcceptPdu matterAcceptPdu);


    /**
     * 查看事项受理条件
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/accept/info")
    Rest<MatterAcceptPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterAcceptFallbackFactory implements FallbackFactory<IMatterAcceptFeign> {

    @Override
    public IMatterAcceptFeign create(Throwable throwable) {
        return new IMatterAcceptFeign(){

            @Override
            public Rest<RespData<List<MatterAcceptPdu>>> list(MatterAcceptPdu matterAcceptPdu) {
                return Rest.fail("暂时无法获取事项受理条件列表，请稍后再试!");
            }

            @Override
            public Rest<MatterAcceptPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项受理条件，请稍后再试!");
            }
        };
    }
}