package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterChargesPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterChargesFallbackFactory.class)
public interface IMatterChargesFeign extends IFeign {
    /**
     * 查看事项收费标准列表
     *
     * @param matterChargesPdu
     * @return
     */
    @PostMapping(value = "/matter/charges/list")
    Rest<RespData<List<MatterChargesPdu>>> list(@RequestBody MatterChargesPdu matterChargesPdu);


    /**
     * 查看事项收费标准
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/charges/info")
    Rest<MatterChargesPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterChargesFallbackFactory implements FallbackFactory<IMatterChargesFeign> {

    @Override
    public IMatterChargesFeign create(Throwable throwable) {
        return new IMatterChargesFeign(){

            @Override
            public Rest<RespData<List<MatterChargesPdu>>> list(MatterChargesPdu matterChargesPdu) {
                return Rest.fail("暂时无法获取事项收费标准列表，请稍后再试!");
            }

            @Override
            public Rest<MatterChargesPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项收费标准列表，请稍后再试!");
            }
        };
    }
}