package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterDatumPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterDatumFallbackFactory.class)
public interface IMatterDatumFeign extends IFeign {
    /**
     * 查看事项申请材料业务列表
     *
     * @param matterDatumPdu
     * @return
     */
    @PostMapping(value = "/matter/datum/list")
    Rest<RespData<List<MatterDatumPdu>>> list(@RequestBody MatterDatumPdu matterDatumPdu);


    /**
     * 查看事项申请材料业务
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/datum/info")
    Rest<MatterDatumPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterDatumFallbackFactory implements FallbackFactory<IMatterDatumFeign> {

    @Override
    public IMatterDatumFeign create(Throwable throwable) {
        return new IMatterDatumFeign(){

            @Override
            public Rest<RespData<List<MatterDatumPdu>>> list(MatterDatumPdu matterDatumPdu) {
                return Rest.fail("暂时无法获取事项申请材料业务列表，请稍后再试!");
            }

            @Override
            public Rest<MatterDatumPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项申请材料业务详细，请稍后再试!");
            }

        };
    }
}