package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterDatumFilePdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterDatumFileFallbackFactory.class)
public interface IMatterDatumFileFeign extends IFeign {
    /**
     * 查看材料附件业务列表
     *
     * @param matterDatumFilePdu
     * @return
     */
    @PostMapping(value = "/matter/datum/file/list")
    Rest<RespData<List<MatterDatumFilePdu>>> list(@RequestBody MatterDatumFilePdu matterDatumFilePdu);


    /**
     * 查看材料附件业务
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/datum/file/info")
    Rest<MatterDatumFilePdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterDatumFileFallbackFactory implements FallbackFactory<IMatterDatumFileFeign> {

    @Override
    public IMatterDatumFileFeign create(Throwable throwable) {
        return new IMatterDatumFileFeign(){
            @Override
            public Rest<RespData<List<MatterDatumFilePdu>>> list(MatterDatumFilePdu matterDatumFilePdu) {
                return Rest.fail("暂时无法获取材料附件业务列表，请稍后再试!");
            }

            @Override
            public Rest<MatterDatumFilePdu> info(Long id) {
                return Rest.fail("暂时无法获取材料附件业务详细，请稍后再试!");
            }
        };
    }
}
