package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterFallbackFactory.class)
public interface IMatterFeign extends IFeign {
    /**
     * 查看基础事项列表
     *
     * @param matterPdu
     * @return
     */
    @PostMapping(value = "/matter/list")
    Rest<RespData<List<MatterPdu>>> list(@RequestBody MatterPdu matterPdu);


    /**
     * 查看基础事项
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/info")
    Rest<MatterPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterFallbackFactory implements FallbackFactory<IMatterFeign> {

    @Override
    public IMatterFeign create(Throwable throwable) {
        return new IMatterFeign(){

            @Override
            public Rest<RespData<List<MatterPdu>>> list(MatterPdu matterPdu) {
                return Rest.fail("暂时无法获取基础事项列表，请稍后再试!");
            }

            @Override
            public Rest<MatterPdu> info(Long id) {
                return Rest.fail("暂时无法获取基础事项，请稍后再试!");
            }
        };
    }
}