package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterFlowlimitPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterFlowlimitFallbackFactory.class)
public interface IMatterFlowlimitFeign extends IFeign {
    /**
     * 查看事项办理流程列表
     *
     * @param matterFlowlimitPdu
     * @return
     */
    @PostMapping(value = "/matter/flowlimit/list")
    Rest<RespData<List<MatterFlowlimitPdu>>> list(@RequestBody MatterFlowlimitPdu matterFlowlimitPdu);


    /**
     * 查看事项办理流程
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/flowlimit/info")
    Rest<MatterFlowlimitPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterFlowlimitFallbackFactory implements FallbackFactory<IMatterFlowlimitFeign> {

    @Override
    public IMatterFlowlimitFeign create(Throwable throwable) {
        return new IMatterFlowlimitFeign(){

            @Override
            public Rest<RespData<List<MatterFlowlimitPdu>>> list(MatterFlowlimitPdu matterFlowlimitPdu) {
                return Rest.fail("暂时无法获取事项办理流程列表，请稍后再试!");
            }

            @Override
            public Rest<MatterFlowlimitPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项办理流程，请稍后再试!");
            }
        };
    }
}
