package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterIntermediaryPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterIntermediaryFallbackFactory.class)
public interface IMatterIntermediaryFeign extends IFeign {
    /**
     * 查看事项中介服务列表
     *
     * @param matterIntermediaryPdu
     * @return
     */
    @PostMapping(value = "/matter/intermediary/list")
    Rest<RespData<List<MatterIntermediaryPdu>>> list(@RequestBody MatterIntermediaryPdu matterIntermediaryPdu);


    /**
     * 查看事项中介服务
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/intermediary/info")
    Rest<MatterIntermediaryPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterIntermediaryFallbackFactory implements FallbackFactory<IMatterIntermediaryFeign> {

    @Override
    public IMatterIntermediaryFeign create(Throwable throwable) {
        return new IMatterIntermediaryFeign(){

            @Override
            public Rest<RespData<List<MatterIntermediaryPdu>>> list(MatterIntermediaryPdu matterIntermediaryPdu) {
                return Rest.fail("暂时无法获取事项中介服务列表，请稍后再试!");
            }

            @Override
            public Rest<MatterIntermediaryPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项中介服务，请稍后再试!");
            }
        };
    }
}
