package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterQuestionPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterQuestionFallbackFactory.class)
public interface IMatterQuestionFeign extends IFeign {
    /**
     * 查看事项常见问题列表
     *
     * @param matterQuestionPdu
     * @return
     */
    @PostMapping(value = "/matter/question/list")
    Rest<RespData<List<MatterQuestionPdu>>> list(@RequestBody MatterQuestionPdu matterQuestionPdu);


    /**
     * 查看事项常见问题
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/question/info")
    Rest<MatterQuestionPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterQuestionFallbackFactory implements FallbackFactory<IMatterQuestionFeign> {

    @Override
    public IMatterQuestionFeign create(Throwable throwable) {
        return new IMatterQuestionFeign(){

            @Override
            public Rest<RespData<List<MatterQuestionPdu>>> list(MatterQuestionPdu matterQuestionPdu) {
                return Rest.fail("暂时无法获取事项常见问题列表，请稍后再试!");
            }

            @Override
            public Rest<MatterQuestionPdu> info(Long id) {
                return Rest.fail("暂时无法获取事项常见问题，请稍后再试!");
            }
        };
    }
}
