package com.mortals.xhx.feign.matter;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.matter.MatterSetbasePdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = MatterSetbaseFallbackFactory.class)
public interface IMatterSetbaseFeign extends IFeign {
    /**
     * 查看事项设定依据列表
     *
     * @param matterSetbasePdu
     * @return
     */
    @PostMapping(value = "/matter/setbase/list")
    Rest<RespData<List<MatterSetbasePdu>>> list(@RequestBody MatterSetbasePdu matterSetbasePdu);


    /**
     * 查看事项设定依据
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/matter/setbase/info")
    Rest<MatterSetbasePdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class MatterSetbaseFallbackFactory implements FallbackFactory<IMatterSetbaseFeign> {

    @Override
    public IMatterSetbaseFeign create(Throwable throwable) {
        return new IMatterSetbaseFeign(){

            @Override
            public Rest<RespData<List<MatterSetbasePdu>>> list(MatterSetbasePdu matterSetbasePdu) {
                return Rest.fail("暂时无法获取事项设定依据列表，请稍后再试!");
            }

            @Override
            public Rest<MatterSetbasePdu> info(Long id) {
                return Rest.fail("暂时无法获取事项设定依据，请稍后再试!");
            }
        };
    }
}