package com.mortals.xhx.feign.site;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.site.SiteThemePdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = SiteThemeFallbackFactory.class)
public interface ISiteThemeFeign extends IFeign {
    /**
     * 查看事项主题列表
     *
     * @param siteThemePdu
     * @return
     */
    @PostMapping(value = "/site/theme/list")
    Rest<RespData<List<SiteThemePdu>>> list(@RequestBody SiteThemePdu siteThemePdu);


    /**
     * 查看事项主题
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/site/theme/info")
    Rest<SiteThemePdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class SiteThemeFallbackFactory implements FallbackFactory<ISiteThemeFeign> {

    @Override
    public ISiteThemeFeign create(Throwable throwable) {
        return new ISiteThemeFeign(){

            @Override
            public Rest<RespData<List<SiteThemePdu>>> list(SiteThemePdu siteThemePdu) {
                return Rest.fail("暂时无法获取事项主题列表，请稍后再试!");
            }

            @Override
            public Rest<SiteThemePdu> info(Long id) {
                return Rest.fail("暂时无法获取事项主题，请稍后再试!");
            }
        };
    }
}