package com.mortals.xhx.feign.site;

import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.site.SiteThemeMatterPdu;
import com.mortals.xhx.feign.IFeign;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(name = "base-manager", path = "/base", fallbackFactory = SiteThemeMatterFallbackFactory.class)
public interface ISiteThemeMatterFeign extends IFeign {
    /**
     * 查看站点主题事项列表
     *
     * @param siteThemeMatterPdu
     * @return
     */
    @PostMapping(value = "/site/theme/matter/list")
    Rest<RespData<List<SiteThemeMatterPdu>>> list(@RequestBody SiteThemeMatterPdu siteThemeMatterPdu);


    /**
     * 查看站点主题事项
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/site/theme/matter/info")
    Rest<SiteThemeMatterPdu> info(@RequestParam(value = "id") Long id);
}

@Slf4j
@Component
class SiteThemeMatterFallbackFactory implements FallbackFactory<ISiteThemeMatterFeign> {

    @Override
    public ISiteThemeMatterFeign create(Throwable throwable) {
        return new ISiteThemeMatterFeign(){

            @Override
            public Rest<RespData<List<SiteThemeMatterPdu>>> list(SiteThemeMatterPdu siteThemeMatterPdu) {
                return Rest.fail("暂时无法获取站点主题事项列表，请稍后再试!");
            }

            @Override
            public Rest<SiteThemeMatterPdu> info(Long id) {
                return Rest.fail("暂时无法获取站点主题事项，请稍后再试!");
            }
        };
    }
}
