-- ----------------------------
-- 桌面终端应用编排表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_sst_apps_desk`;
CREATE TABLE mortals_xhx_sst_apps_desk(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20) NOT NULL     COMMENT '站点id',
    `appId` bigint(20) NOT NULL     COMMENT '应用id',
    `name` varchar(64)      COMMENT '应用名称',
    `describe` varchar(64)      COMMENT '应用描述',
    `url` varchar(128)      COMMENT '应用访问地址',
    `showBasic` tinyint(2)    DEFAULT '1'  COMMENT '是否展示基础应用1是0否',
    `basicSort` int(4)      COMMENT '基础应用排序号',
    `showHot` tinyint(2)    DEFAULT '1'  COMMENT '是否展示热门应用1是0否',
    `hotSort` int(4)      COMMENT '热门应用排序号',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='桌面终端应用编排';

-- ----------------------------
-- 申报事项表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_apply`;
CREATE TABLE mortals_sys_matter_apply(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `siteName` varchar(255)      COMMENT '站点名称',
    `siteMatterId` bigint(20)      COMMENT '站点事项id',
    `matterId` bigint(20)      COMMENT '基础事项ID',
    `matterName` varchar(1024)      COMMENT '事项名称',
    `matterCode` varchar(512)      COMMENT '事项编码',
    `deptId` bigint(20)      COMMENT '部门ID',
    `deptName` varchar(128)      COMMENT '部门名称',
    `deptCode` varchar(255)      COMMENT '部门编码',
    `themeCode` varchar(255)      COMMENT '事项主题编码',
    `themeName` varchar(255)      COMMENT '事项主题名称',
    `source` tinyint(2)      COMMENT '事项来源',
    `reportCount` int(8)    DEFAULT '0'  COMMENT '申报次数',
    `datumCount` int(8)    DEFAULT '0'  COMMENT '材料数量',
    `govUrl` varchar(255)      COMMENT '政务网地址',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='申报事项';

-- ----------------------------
-- 事项材料表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum`;
CREATE TABLE mortals_sys_matter_datum(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `siteName` varchar(255)      COMMENT '站点名称',
    `matterId` bigint(20)      COMMENT '事项id',
    `matterCode` varchar(512)      COMMENT '事项编码',
    `shortName` varchar(512)      COMMENT '材料简称',
    `fullName` varchar(512)      COMMENT '材料全称',
    `needType` tinyint(2)    DEFAULT '0'  COMMENT '是否必要0不选1必要2非必要',
    `datumType` tinyint(2)    DEFAULT '0'  COMMENT '材料形式0不选1纸质2电子3纸质-电子',
    `needOriginal` tinyint(2)    DEFAULT '0'  COMMENT '提交原件0不需要1需要',
    `uselType` tinyint(2)    DEFAULT '1'  COMMENT '使用方式（1.拍照上传，2.在线填写)',
    `suggest` tinyint(2)    DEFAULT '0'  COMMENT '是否推荐（0否1是）',
    `fillSum` int(8)    DEFAULT '1'  COMMENT '填写次数',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='事项材料';



-- ----------------------------
-- 材料附件表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_matter_datum_file`;
CREATE TABLE mortals_sys_matter_datum_file(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `datumId` bigint(20) NOT NULL     COMMENT '材料id',
    `matterId` bigint(20)      COMMENT '事项id',
    `matterCode` varchar(512)      COMMENT '事项编码',
    `fileName` varchar(255)      COMMENT '附件名称',
    `filetype` tinyint(2)    DEFAULT '1'  COMMENT '附件类型 (1.示例样表，2.空白表格)',
    `templatePath` varchar(255)      COMMENT '模板地址',
    `samplePath` varchar(255)      COMMENT '样表地址',
    `previewUrl` varchar(255)      COMMENT '样表预览地址',
    `formContent` text      COMMENT '模板表单内容',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='材料附件';


-- ----------------------------
-- 站点材料公共库表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_sys_datum_library`;
CREATE TABLE mortals_sys_datum_library(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `siteName` varchar(255)      COMMENT '站点名称',
    `datumId` bigint(20)      COMMENT '材料id',
    `shortName` varchar(512)      COMMENT '材料简称',
    `fullName` varchar(512)      COMMENT '材料全称',
    `needType` tinyint(2)    DEFAULT '0'  COMMENT '是否必要0不选1必要2非必要',
    `datumType` tinyint(2)    DEFAULT '0'  COMMENT '材料形式0不选1纸质2电子3纸质-电子',
    `needOriginal` tinyint(2)    DEFAULT '0'  COMMENT '提交原件0不需要1需要',
    `uselType` tinyint(2)    DEFAULT '1'  COMMENT '使用方式（1.拍照上传，2.在线填写)',
    `suggest` tinyint(2)    DEFAULT '0'  COMMENT '是否推荐（0否1是）',
    `fillSum` int(8)    DEFAULT '1'  COMMENT '填写次数',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='站点材料公共库';


-- ----------------------------
-- 用户申报信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user_matter_apply`;
CREATE TABLE mortals_xhx_user_matter_apply(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `userId` bigint(20) NOT NULL     COMMENT '站点id',
    `matterId` bigint(20)      COMMENT '事项ID',
    `matterName` varchar(1024)      COMMENT '事项名称',
    `matterCode` varchar(512)      COMMENT '事项编码',
    `applyCode` varchar(512)      COMMENT '申报编号',
    `applyAddr` varchar(512)      COMMENT '申报地址',
    `deviceName` varchar(512)      COMMENT '申报设备名称',
    `applyPerson` varchar(512)      COMMENT '申请人姓名',
    `phoneNum` varchar(128)      COMMENT '联系电话',
    `idCard` varchar(128)      COMMENT '证件号码',
    `deptName` varchar(128)      COMMENT '事项所属部门',
    `applyDate` datetime      COMMENT '申报时间',
    `status` tinyint(2)    DEFAULT '0'  COMMENT '受理状态0未受理1已受理',
    `applyWay` varchar(128)      COMMENT '申报方式',
    `storeDevice` varchar(128)      COMMENT '存储设备',
    `boxNum` varchar(128)      COMMENT '箱体编号',
    `storeDate` datetime      COMMENT '存件时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户申报信息';

-- ----------------------------
-- 用户申报明细表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user_matter_details`;
CREATE TABLE mortals_xhx_user_matter_details(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `applyrId` bigint(20) NOT NULL     COMMENT '用户申报id',
    `datumId` bigint(20)      COMMENT '材料id',
    `matterId` bigint(20)      COMMENT '事项id',
    `matterCode` varchar(512)      COMMENT '事项编码',
    `shortName` varchar(512)      COMMENT '材料简称',
    `fullName` varchar(512)      COMMENT '材料全称',
    `fileName` varchar(255)      COMMENT '附件名称',
    `previewUrl` varchar(255)      COMMENT '文件预览地址',
    `formContent` text      COMMENT '填单表单内容',
    `formTemplate` text      COMMENT '填单表单模板',
    `templateUrl` varchar(255)      COMMENT '模板文件地址',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户申报明细';

-- ----------------------------
-- 用户申报事项审批表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_user_matter_examine`;
CREATE TABLE mortals_xhx_user_matter_examine(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `applyrId` bigint(20) NOT NULL     COMMENT '用户申报id',
    `acceptPerson` varchar(64)      COMMENT '受理人员',
    `acceptResult` tinyint(2)      COMMENT '受理结果1通过2拒绝',
    `acceptOpinion` varchar(512)      COMMENT '受理意见',
    `acceptDate` datetime      COMMENT '受理时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户申报事项审批';

ALTER TABLE `mortals_xhx_sst_basic` ADD COLUMN `countdown` tinyint(2)   DEFAULT '0'  COMMENT '操作倒计时单位分' AFTER `elderEnable`;

-- ----------------------------
-- 网点信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_converge_site`;
CREATE TABLE mortals_xhx_converge_site(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `branchName` varchar(100)      COMMENT '网点名称',
    `branchLogo` varchar(50)      COMMENT '网点标识',
    `status` char(1)      COMMENT '网点服务状态，正常Y异常N',
    `serverTime` varchar(100)      COMMENT '网点服务时间',
    `consultPhone` varchar(100) NOT NULL     COMMENT '网点咨询电话',
    `branchStyle` char(1)      COMMENT '网点类型',
    `address` varchar(200)      COMMENT '网点地址',
    `opr` char(1)      COMMENT '操作类型',
    `siteId` bigint(20)      COMMENT '站点id',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='网点信息';
-- ----------------------------
-- 网点设备表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_converge_device`;
CREATE TABLE mortals_xhx_converge_device(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `branchId` bigint(20)      COMMENT '网点ID',
    `equipmentName` varchar(100)      COMMENT '设备名称',
    `systemName` char(1)      COMMENT '设备系统类型',
    `logo` varchar(100)      COMMENT '设备标识，具有唯一性',
    `industry` varchar(100)      COMMENT '设备所属行业',
    `isAbnormal` char(1) NOT NULL     COMMENT '设备运行状态',
    `opr` char(1)      COMMENT '操作类型',
    `siteId` bigint(20)      COMMENT '站点id',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='网点设备';
-- ----------------------------
-- 设备应用表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_converge_apps`;
CREATE TABLE mortals_xhx_converge_apps(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `siteId` bigint(20)      COMMENT '站点id',
    `equipmentId` bigint(20)      COMMENT '设备ID',
    `appEname` varchar(100)      COMMENT '应用标识，具有唯一性',
    `appName` varchar(100)      COMMENT '应用名称',
    `appSimpleName` varchar(100)      COMMENT '应用简称',
    `provider` varchar(100)      COMMENT '应用提供方',
    `origin` char(1)      COMMENT '应用来源',
    `totalPv` int(8)      COMMENT '应用访问数',
    `totalUv` int(8)      COMMENT '应用访客数',
    `opr` char(1)      COMMENT '操作类型',
    `statYearMonth` varchar(100)      COMMENT '统计月份，格式yyyy-MM-dd',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='设备应用';


INSERT INTO `mortals_xhx_task` (`name`, `taskKey`, `status`, `excuteService`, `excuteParam`, `excuteHost`, `excuteStrategy`, `excuteDate`, `excuteTime`, `remark`, `lastExcuteHost`, `lastExcuteTime`, `interimExcuteStatus`, `createTime`, `createUserId`, `createUserName`) VALUES ('省平台数据汇聚任务', 'provinceConvergeTask', '0', 'ProvinceConvergeTask', NULL, NULL, '1', '0', '23:30', NULL, NULL, NULL, '0', NOW(), '1', '系统管理员');

DROP TABLE IF EXISTS `mortals_xhx_converge_apps_access`;
CREATE TABLE `mortals_xhx_converge_apps_access` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `siteId` bigint(20) DEFAULT NULL COMMENT '站点id',
  `applicationId` varchar(128) DEFAULT NULL COMMENT '应用ID',
  `applicationName` varchar(128) DEFAULT NULL COMMENT '应用名称',
  `startTime` datetime DEFAULT NULL COMMENT '应用打开时间',
  `endTime` datetime DEFAULT NULL COMMENT '应用关闭时间',
  `userId` varchar(128) DEFAULT NULL COMMENT '用户ID',
  `userName` varchar(128) DEFAULT NULL COMMENT '用户名称',
  `channelId` varchar(128) DEFAULT NULL COMMENT '渠道ID',
  `channelName` varchar(128) DEFAULT NULL COMMENT '渠道名称',
  `location` varchar(128) DEFAULT NULL COMMENT '地域',
  `clientName` varchar(128) DEFAULT NULL COMMENT '客户端名称',
  `version` varchar(128) DEFAULT NULL COMMENT '客户端版本号',
  `ecode` varchar(128) DEFAULT NULL COMMENT '设备唯一标识',
  `appSimpleName` varchar(128) DEFAULT NULL COMMENT '应用简称',
  `provider` varchar(128) DEFAULT NULL COMMENT '应用提供方',
  `origin` varchar(1) DEFAULT NULL COMMENT '应用来源',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8 COMMENT='应用访问';

ALTER TABLE `mortals_xhx_sst_apps_desk` ADD COLUMN `clickSum` int(8) DEFAULT '0' COMMENT '应用点击次数';
ALTER TABLE `mortals_xhx_sst_apps` ADD COLUMN `clickSum` int(8) DEFAULT '0' COMMENT '应用点击次数';

ALTER TABLE `mortals_xhx_sst_agreement` ADD COLUMN `protocolType` tinyint(2)  DEFAULT '1'  COMMENT '协议类型' AFTER `name`;
INSERT INTO `mortals_xhx_param` (`name`, `firstOrganize`, `secondOrganize`, `paramKey`, `paramValue`, `validStatus`, `modStatus`, `displayType`, `remark`, `createTime`, `createUserId`, `createUserName`) VALUES ('协议类型', 'SstAgreement', 'protocolType', '1', '注册协议', '1', '4', '0', NULL, NULL, NULL, NULL);
INSERT INTO `mortals_xhx_param` (`name`, `firstOrganize`, `secondOrganize`, `paramKey`, `paramValue`, `validStatus`, `modStatus`, `displayType`, `remark`, `createTime`, `createUserId`, `createUserName`) VALUES ('协议类型', 'SstAgreement', 'protocolType', '2', '申报协议', '1', '4', '0', NULL, NULL, NULL, NULL);

DROP TABLE IF EXISTS `mortals_xhx_converge_apps_interface`;
CREATE TABLE `mortals_xhx_converge_apps_interface` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '序号，主键，自增长',
  `ecode` varchar(128) DEFAULT NULL COMMENT '设备唯一标识',
  `applicationId` varchar(128) DEFAULT NULL COMMENT '应用ID',
  `interfaceUniqueId` varchar(128) DEFAULT NULL COMMENT '接口标识',
  `interfaceName` varchar(128) DEFAULT NULL COMMENT '接口名称',
  `totalInvokeSum` int(8) DEFAULT NULL COMMENT '接口调用次数',
  `createTime` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8 COMMENT='应用接口';