package com.mortals.xhx.daemon.task;

import com.mortals.framework.exception.AppException;
import com.mortals.framework.service.ITask;
import com.mortals.framework.service.ITaskExcuteService;
import com.mortals.framework.util.DateUtils;
import com.mortals.xhx.feign.site.ISiteFeign;
import com.mortals.xhx.module.converge.model.ConvergeAppsAccessEntity;
import com.mortals.xhx.module.converge.service.ConvergeAppsService;
import com.mortals.xhx.module.converge.service.ConvergeDeviceService;
import com.mortals.xhx.module.converge.service.ConvergeSiteService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

/**
 * 省平台数据汇聚任务
 */
@Slf4j
@Service("ProvinceConvergeTask")
public class ProvinceConvergeTaskImpl implements ITaskExcuteService {

    @Autowired
    private ConvergeSiteService convergeSiteService;
    @Autowired
    private ConvergeDeviceService convergeDeviceService;
    @Autowired
    private ConvergeAppsService convergeAppsService;

    @Override
    public void excuteTask(ITask task) throws AppException {
        log.info("开始执行省平台数据汇聚任务...");
        try {
            convergeSiteService.doConvergeSite();

        }catch (Exception e){
            log.error("汇聚网点数据执行出错",e);
        }
        try {
            convergeDeviceService.doConvergeDevice();

        }catch (Exception e){
            log.error("汇聚设备数据出错",e);
        }
        try {
            SimpleDateFormat format=new SimpleDateFormat("yyyy-MM-dd");
            Calendar calendar=Calendar.getInstance();
            calendar.set(Calendar.DAY_OF_MONTH, 1);
            String startTime = format.format(calendar.getTime());
            calendar.set(Calendar.DAY_OF_MONTH, calendar.getActualMaximum(Calendar.DAY_OF_MONTH));
            String endTime = format.format(calendar.getTime());
            Map<String,String> condition = new HashMap<>();
            condition.put("startTime",startTime);
            condition.put("endTime",endTime);
            convergeAppsService.doConvergeApps(condition);

        }catch (Exception e){
            log.error("汇聚应用数据出错",e);
        }
        log.info("省平台数据汇聚任务执行完成");
    }

    @Override
    public void stopTask(ITask task) throws AppException {

    }

}
