package com.mortals.xhx.module.converge.service.impl;
import com.mortals.xhx.module.converge.model.*;
import com.mortals.xhx.module.converge.model.vo.AppsAccessVo;
import com.mortals.xhx.module.converge.service.ConvergeAppsAccessService;
import com.mortals.xhx.module.converge.service.ConvergeDeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.converge.dao.ConvergeAppsDao;
import com.mortals.xhx.module.converge.service.ConvergeAppsService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
* ConvergeAppsService
* 设备应用 service实现
*
* @author zxfei
* @date 2023-06-12
*/
@Service("convergeAppsService")
@Slf4j
public class ConvergeAppsServiceImpl extends AbstractCRUDServiceImpl<ConvergeAppsDao, ConvergeAppsEntity, Long> implements ConvergeAppsService {

    @Autowired
    private ConvergeAppsAccessService convergeAppsAccessService;
    @Autowired
    private ConvergeDeviceService convergeDeviceService;

    @Override
    public void doConvergeApps(Map<String,String> condition) throws AppException {
        List<AppsAccessVo> accessPvList = convergeAppsAccessService.getAppsAccessPv(condition);
        List<AppsAccessVo> accessUvList = convergeAppsAccessService.getAppsAccessUv(condition);
        if(CollectionUtils.isEmpty(accessPvList)||CollectionUtils.isEmpty(accessUvList)){
            return;
        }else {
            Map<String,AppsAccessVo> uvMap = new HashMap<>();
            for (AppsAccessVo vo:accessUvList){
                String key = vo.getSiteId()+"_"+vo.getEquipmentId()+"_"+vo.getAppEname()+"_"+vo.getStatYearMonth();
                uvMap.put(key,vo);
            }
            List<ConvergeAppsEntity> appsList = new ArrayList<>();
            Map<String, ConvergeDeviceEntity> deviceMap = new HashMap<>();
            for(AppsAccessVo item:accessPvList){
                ConvergeAppsEntity entity = new ConvergeAppsEntity();
                if(deviceMap.containsKey(item.getEquipmentId())){
                    entity.setEquipmentId(deviceMap.get(item.getEquipmentId()).getId());
                }else {
                    ConvergeDeviceEntity deviceEntity = convergeDeviceService.selectOne(new ConvergeDeviceQuery().logo(item.getEquipmentId()));
                    if(deviceEntity!=null){
                        deviceMap.put(item.getEquipmentId(),deviceEntity);
                        entity.setEquipmentId(deviceEntity.getId());
                    }else {
                        entity.setEquipmentId(-1l);
                    }
                }
                entity.setAppEname(item.getAppEname());
                entity.setAppName(item.getAppName());
                entity.setAppSimpleName(item.getAppSimpleName());
                entity.setProvider(item.getProvider());
                entity.setOrigin(item.getOrigin());
                entity.setSiteId(item.getSiteId());
                entity.setTotalPv(item.getTotalPv());
                entity.setStatYearMonth(item.getStatYearMonth());
                String key = item.getSiteId()+"_"+item.getEquipmentId()+"_"+item.getAppEname()+"_"+item.getStatYearMonth();
                if(uvMap.containsKey(key)) {
                    entity.setTotalUv(uvMap.get(key).getTotalUv());
                }
                appsList.add(entity);
            }

            for(ConvergeAppsEntity item:appsList){
                ConvergeAppsEntity temp = this.selectOne(new ConvergeAppsQuery().appEname(item.getAppEname()).equipmentId(item.getEquipmentId()).siteId(item.getSiteId()).statYearMonth(item.getStatYearMonth()));
                if(temp!=null){
                    item.setId(temp.getId());
                    if(temp.getTotalPv()==item.getTotalPv()&&temp.getTotalUv()==item.getTotalUv()){
                        item.setOpr("P");
                    }else {
                        item.setOpr("U");
                    }
                    this.update(item);
                }else {
                    item.setOpr("A");
                    this.save(item);
                }
            }
        }
    }
}