package com.mortals.xhx.module.converge.service.impl;
import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.device.DevicePdu;
import com.mortals.xhx.feign.device.IDeviceFeign;
import com.mortals.xhx.module.converge.model.ConvergeDeviceQuery;
import com.mortals.xhx.module.converge.model.ConvergeSiteEntity;
import com.mortals.xhx.module.converge.model.ConvergeSiteQuery;
import com.mortals.xhx.module.converge.service.ConvergeSiteService;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.converge.dao.ConvergeDeviceDao;
import com.mortals.xhx.module.converge.model.ConvergeDeviceEntity;
import com.mortals.xhx.module.converge.service.ConvergeDeviceService;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.List;

/**
* ConvergeDeviceService
* 网点设备 service实现
*
* @author zxfei
* @date 2023-06-12
*/
@Service("convergeDeviceService")
@Slf4j
public class ConvergeDeviceServiceImpl extends AbstractCRUDServiceImpl<ConvergeDeviceDao, ConvergeDeviceEntity, Long> implements ConvergeDeviceService {

    @Autowired
    private IDeviceFeign deviceFeign;
    @Autowired
    private ConvergeSiteService convergeSiteService;

    @Override
    public void doConvergeDevice() throws AppException {
        DevicePdu devicePdu = new DevicePdu();
        devicePdu.setSize(-1);
        devicePdu.setProductName("自助服务终端");
        Rest<RespData<List<DevicePdu>>> rest = deviceFeign.list(devicePdu);
        List<ConvergeDeviceEntity> deviceList = new ArrayList<>();
        if(rest.getCode() > 0) {
            for(DevicePdu device:rest.getData().getData()){
                ConvergeDeviceEntity convergeDeviceEntity = convertByDevicePdu(device);
                deviceList.add(convergeDeviceEntity);
            }
        }
        devicePdu.setProductName("桌面式自助服务终端");
        rest = deviceFeign.list(devicePdu);
        if(rest.getCode() > 0) {
            for(DevicePdu device:rest.getData().getData()){
                ConvergeDeviceEntity convergeDeviceEntity = convertByDevicePdu(device);
                deviceList.add(convergeDeviceEntity);
            }
        }
        for(ConvergeDeviceEntity entity:deviceList){
            ConvergeDeviceEntity temp = this.selectOne(new ConvergeDeviceQuery().logo(entity.getLogo()));
            if(temp == null){
                ConvergeSiteEntity siteEntity = convergeSiteService.selectOne(new ConvergeSiteQuery().siteId(entity.getSiteId()));
                if(siteEntity!=null){
                    entity.setBranchId(siteEntity.getId());
                }
                entity.setOpr("A");
                this.save(entity);
            }else {
                if(equals(temp,entity)){
                    entity.setOpr("P");
                }else {
                    entity.setOpr("U");
                }
                entity.setId(temp.getId());
                this.update(entity);
            }
        }
    }

    private ConvergeDeviceEntity convertByDevicePdu(DevicePdu devicePdu){
        ConvergeDeviceEntity entity = new ConvergeDeviceEntity();
        entity.setEquipmentName(devicePdu.getDeviceName());
        if(devicePdu.getProductName().equals("自助服务终端")){
            entity.setSystemName("2");  //windows
        }else {
            entity.setSystemName("1");  //android
        }
        entity.setLogo(devicePdu.getDeviceCode());
        entity.setIndustry("政务服务");
        if(devicePdu.getDeviceStatus()==2){
            entity.setIsAbnormal("Y");
        }else {
            entity.setIsAbnormal("N");
        }
        entity.setSiteId(devicePdu.getSiteId());
        return entity;
    }

    private boolean equals(ConvergeDeviceEntity temp,ConvergeDeviceEntity entity){
        if(!temp.getLogo().equals(entity.getLogo())){
            return false;
        }
        if(!temp.getEquipmentName().equals(entity.getEquipmentName())){
            return false;
        }
        if(!temp.getIsAbnormal().equals(entity.getIsAbnormal())){
            return false;
        }
        return true;
    }
}