package com.mortals.xhx.module.device.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.RepeatSubmit;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.BaseEntity;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.service.IUser;
import com.mortals.framework.utils.ReflectUtils;
import com.mortals.framework.utils.poi.ExcelUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.device.DeviceAlarmPdu;
import com.mortals.xhx.common.pdu.device.DeviceModuleUsePdu;
import com.mortals.xhx.common.pdu.device.DeviceNotifyPdu;
import com.mortals.xhx.common.pdu.device.DevicePdu;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.feign.device.IDeviceAlarmFeign;
import com.mortals.xhx.feign.device.IDeviceFeign;
import com.mortals.xhx.feign.device.IDeviceModuleUseFeign;
import com.mortals.xhx.module.device.model.DeviceEntity;
import com.mortals.xhx.module.device.model.DeviceOpenBoxPdu;
import com.mortals.xhx.module.device.service.DeviceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 设备
 *
 * @author zxfei
 * @date 2022-06-27
 */
@RestController
@RequestMapping("device")
@Slf4j
public class DeviceController extends BaseCRUDJsonBodyMappingController<DeviceService, DeviceEntity, Long> {

    @Autowired
    private IDeviceFeign deviceFeign;

    @Autowired
    private IDeviceAlarmFeign deviceAlarmFeign;

    @Autowired
    private IDeviceModuleUseFeign deviceModuleUseFeign;

    @Override
    @PostMapping({"list"})
    @UnAuth
    public Rest<Object> list(@RequestBody DeviceEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();

        int code;
        try {
            PageInfo pageInfo = this.buildPageInfo(query);
            this.doListBefore(query, model, context);
            Result<DeviceEntity> result = this.getService().find(query, pageInfo, context);
            model.put("data", result.getList());
            int onlineTotal = 0;
            int offlineTotal = 0;
            int not_active = 0;
            int stop_using = 0;
            for(DeviceEntity deviceEntity:result.getList()){
                if(deviceEntity.getDeviceStatus()==0){
                    not_active++;
                }
                if(deviceEntity.getDeviceStatus()==1){
                    offlineTotal++;
                }
                if(deviceEntity.getDeviceStatus()==2){
                    onlineTotal++;
                }
                if(deviceEntity.getEnabled()==0){
                    stop_using++;
                }
            }
            model.put("online", onlineTotal);
            model.put("offline", offlineTotal);
            model.put("notActive", not_active);
            model.put("stopUsing", stop_using);
            model.put("pageInfo", result.getPageInfo());
            model.put("dict",result.getDict());
            this.parsePageInfo(model, result.getPageInfo());
            code = this.doListAfter(query, model, context);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @RequestMapping(value = {"info"},method = {RequestMethod.POST, RequestMethod.GET})
    @UnAuth
    public String info(Long id) {
        Map<String, Object> model = new HashMap();
        if (id == null) {
            return this.createFailJsonResp("请选择待查看" + this.getModuleDesc() + "信息");
        } else {
            JSONObject ret = new JSONObject();
            String busiDesc = "查看" + this.getModuleDesc();
            Context context = this.getContext();

            try {
                DeviceEntity deviceEntity = new DeviceEntity();
                Rest<DevicePdu> result = deviceFeign.info(id);
                if (result.getCode().equals(YesNoEnum.YES.getValue())) {
                    BeanUtils.copyProperties(result.getData(), deviceEntity, BeanUtil.getNullPropertyNames(result.getData()));
                    model.put("dict",result.getDict());
                    model.put("msg",result.getMsg());
                }
                if (deviceEntity == null) {
                    throw new Exception(busiDesc + "，不存在或已被删除");
                }

                ret.put("data", deviceEntity);
                this.recordSysLog(this.request, busiDesc + " 【成功】");
            } catch (Exception var8) {
                this.doException(this.request, busiDesc, model, var8);
                Object msg = model.get("message_info");
                return this.createFailJsonResp(msg == null ? "系统异常" : msg.toString());
            }

            this.init(model, context);
            ret.put("code", 1);
            ret.put("msg", model.remove("message_info"));
            ret.put("dict", model.remove("dict"));
            return ret.toJSONString();
        }
    }

    @PostMapping({"alarm/list"})
    @UnAuth
    public Rest<Object> alarmList(@RequestBody DeviceAlarmPdu query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询设备告警信息列表";

        int code=1;
        try {
            PageInfo pageInfo = new PageInfo();
            if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getPage())) {
                pageInfo.setCurrPage(query.getPage());
            }

            if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getSize())) {
                pageInfo.setPrePageResult(query.getSize());
            }

            DevicePdu devicePdu = new DevicePdu();
            devicePdu.setSiteId(query.getSiteId());
            devicePdu.setProductName("%自助服务终端%");
            Rest<RespData<List<DevicePdu>>> restd = deviceFeign.list(devicePdu);
            if (restd.getCode().equals(YesNoEnum.YES.getValue())) {
                List<Long> deviceIdList = restd.getData().getData().stream().map(item -> {
                    return item.getId();
                }).collect(Collectors.toList());
                query.setAlarmDeviceList(deviceIdList);
            }
            Result<DeviceAlarmPdu> result = new Result();
            Rest<RespData<List<DeviceAlarmPdu>>> rest = deviceAlarmFeign.list(query);
            if (rest.getCode().equals(YesNoEnum.YES.getValue())) {
                List<DeviceAlarmPdu> collect = rest.getData().getData();
                result.setList(collect);
                pageInfo.setTotalResult(collect.size());
                result.setPageInfo(pageInfo);
                result.setDict(rest.getDict());
            }
            model.put("data", result.getList());
            model.put("pageInfo", result.getPageInfo());
            model.put("dict", result.getDict());
            this.parsePageInfo(model, result.getPageInfo());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"module/use/list"})
    @UnAuth
    public Rest<Object> moduleUseList(@RequestBody DeviceModuleUsePdu query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询设备模块使用频率信息列表";

        int code=1;
        try {
            PageInfo pageInfo = new PageInfo();
            if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getPage())) {
                pageInfo.setCurrPage(query.getPage());
            }

            if (!ObjectUtils.isEmpty(query) && !ObjectUtils.isEmpty(query.getSize())) {
                pageInfo.setPrePageResult(query.getSize());
            }
            Result<DeviceModuleUsePdu> result = new Result();
            Rest<RespData<List<DeviceModuleUsePdu>>> rest = deviceModuleUseFeign.list(query);
            if (rest.getCode().equals(YesNoEnum.YES.getValue())) {
                List<DeviceModuleUsePdu> collect = rest.getData().getData();
                result.setList(collect);
                pageInfo.setTotalResult(collect.size());
                result.setPageInfo(pageInfo);
                result.setDict(rest.getDict());
            }
            model.put("data", result.getList());
            model.put("pageInfo", result.getPageInfo());
            model.put("dict", result.getDict());
            this.parsePageInfo(model, result.getPageInfo());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    @PostMapping({"openBox"})
    @UnAuth
    public Rest<Object> openBox(@RequestBody DeviceOpenBoxPdu device) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "设备开柜指令发送";

        int code=1;
        try {
            DeviceNotifyPdu pdu = new DeviceNotifyPdu();
            List<String> deviceCodeList = new ArrayList<>();
            if(StringUtils.isNotEmpty(device.getTargetDevice())){
                deviceCodeList.add(device.getTargetDevice());
            }else {
                DevicePdu devicePdu = new DevicePdu();
                devicePdu.setDeviceStatus(2);
                devicePdu.setEnabled(1);
                devicePdu.setSiteId(device.getSiteId());
                devicePdu.setProductName("取件柜");
                Rest<RespData<List<DevicePdu>>> restd = deviceFeign.list(devicePdu);
                if (restd.getCode().equals(YesNoEnum.YES.getValue())) {
                    if (restd.getData() != null && restd.getData().getData().size() > 0) {
                        deviceCodeList.add(restd.getData().getData().get(0).getDeviceCode());
                    }else {
                        throw new AppException("指令发送失败，没有找到在线的取件柜");
                    }
                }else {
                    throw new AppException("查询设备列表失败");
                }
            }

            if(deviceCodeList.size()==0){
                throw new AppException("指令发送失败，没有找到适配的取件柜");
            }
            pdu.setDeviceCodeList(deviceCodeList);
            pdu.setAction("openBox");
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("zzfwzd",device.getSourceDevice());  //自助服务终端设备编码
            pdu.setContent(jsonObject.toJSONString());
            Rest<String> rest = deviceFeign.downMsg(pdu);
            if(rest.getCode()==1) {
                model.put("message_info", busiDesc + "成功");
            }else {
                code = -1;
                model.put("message_info", busiDesc + "失败");
            }
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }


    @PostMapping({"m/save"})
    @RepeatSubmit
    public String save(@RequestBody DevicePdu devicePdu,@RequestHeader("Authorization") String authorization) {
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "保存" + this.getModuleDesc();

        int code = 1;
        try {

            Rest<RespData<DevicePdu>> rest = deviceFeign.save(devicePdu,authorization);
            if (rest.getCode()>0){
                code = 1;
                model.put("entity", rest.getData().getData());
                model.put("message_info", busiDesc + "成功");
                this.recordSysLog(this.request, busiDesc + " 【成功】 [id:" + devicePdu.getId() + "]");
            }else {
                code = -1;
                model.put("message_info", rest.getMsg());
            }

        } catch (Exception var9) {
            this.doException(this.request, busiDesc, model, var9);
            model.put("entity", devicePdu);
            this.init(model, context);
            code = -1;
        }

        this.init(model, context);
        JSONObject ret = new JSONObject();
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("data", model);
        return ret.toJSONString();
    }

    @PostMapping({"m/list"})
    @UnAuth
    public Rest<Object> mlist(@RequestBody DevicePdu query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();

        int code;
        try {
            Rest<RespData<List<DevicePdu>>> rest = deviceFeign.list(query);
            if (rest.getCode().equals(YesNoEnum.YES.getValue())) {
                model.put("data", rest.getData().getData());
                int onlineTotal = 0;
                int offlineTotal = 0;
                int not_active = 0;
                int stop_using = 0;
                for (DevicePdu deviceEntity : rest.getData().getData()) {
                    if (deviceEntity.getDeviceStatus() == 0) {
                        not_active++;
                    }
                    if (deviceEntity.getDeviceStatus() == 1) {
                        offlineTotal++;
                    }
                    if (deviceEntity.getDeviceStatus() == 2) {
                        onlineTotal++;
                    }
                    if (deviceEntity.getEnabled() == 0) {
                        stop_using++;
                    }
                }
                model.put("online", onlineTotal);
                model.put("offline", offlineTotal);
                model.put("notActive", not_active);
                model.put("stopUsing", stop_using);
                model.put("pageInfo", rest.getData().getPageInfo());
                //model.put("dict", rest.getData().getDict());
            }
            ret.setCode(rest.getCode());
            ret.setMsg(rest.getMsg());
            ret.setData(model);
            ret.setDict(rest.getDict());

        } catch (Exception var9) {
            code = -1;
            ret.setCode(code);
            this.doException(this.request, busiDesc, model, var9);
            ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        }

        return ret;
    }

    /**
     * 设备启用停用
     */
    @PostMapping(value = "m/enable")
    public String deviceEnable(@RequestBody DevicePdu devicePdu,@RequestHeader("Authorization") String authorization) {
        JSONObject jsonObject = new JSONObject();
        Map<String, Object> model = new HashMap<>();
        String busiDesc = "启用停用设备";
        try {
            String resp = deviceFeign.deviceEnable(devicePdu,authorization);

            jsonObject.put(KEY_RESULT_DATA, model);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
        } catch (Exception e) {
            log.error("设备启用停用消息", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }


    @PostMapping({"m/importData"})
    public String importData(MultipartFile file,@RequestHeader("Authorization") String authorization,@RequestParam("siteId") Long siteId) {

        return deviceFeign.importData(file,authorization,siteId);
    }

}