package com.mortals.xhx.module.matter.service.impl;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.PageInfo;
import com.mortals.xhx.common.utils.BeanUtil;
import com.mortals.xhx.module.matter.model.*;
import com.mortals.xhx.module.matter.service.MatterApplyService;
import com.mortals.xhx.module.matter.service.MatterDatumFileService;
import com.mortals.xhx.module.matter.service.MatterDatumService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.matter.dao.DatumLibraryDao;
import com.mortals.xhx.module.matter.service.DatumLibraryService;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
* DatumLibraryService
* 站点材料公共库 service实现
*
* @author zxfei
* @date 2023-04-07
*/
@Service("datumLibraryService")
public class DatumLibraryServiceImpl extends AbstractCRUDServiceImpl<DatumLibraryDao, DatumLibraryEntity, Long> implements DatumLibraryService {

    @Autowired
    private MatterApplyService matterApplyService;

    @Autowired
    private MatterDatumService matterDatumService;

    @Autowired
    private MatterDatumFileService matterDatumFileService;

    @Override
    protected void findAfter(DatumLibraryEntity params, Context context, List<DatumLibraryEntity> list) throws AppException {

        list.stream().peek(item->{
            List<MatterDatumFileEntity> matterDatumFileEntities = matterDatumFileService.find(new MatterDatumFileQuery().datumId(item.getDatumId()));
            item.setMatterDatumFileList(matterDatumFileEntities);
        }).count();
        super.findAfter(params, context, list);
    }

    @Override
    protected void findAfter(DatumLibraryEntity params, PageInfo pageInfo, Context context, List<DatumLibraryEntity> list) throws AppException {
        list.stream().peek(item->{
            List<MatterDatumFileEntity> matterDatumFileEntities = matterDatumFileService.find(new MatterDatumFileQuery().datumId(item.getDatumId()));
            item.setMatterDatumFileList(matterDatumFileEntities);
        }).count();
        super.findAfter(params, pageInfo,context, list);
    }

    @Override
    public Rest<String> addToMatterDatum(String libraryIds, Long matterId, Context context) {
//        if (ObjectUtils.isEmpty(matterId)) {
//            throw new AppException("请选择对应事项");
//        }
        List<Long> libraryIdList = Arrays.asList(libraryIds.split(",")).stream().map(Long::parseLong).collect(Collectors.toList());
        DatumLibraryQuery query = new DatumLibraryQuery();
        query.setIdList(libraryIdList);
        List<DatumLibraryEntity> entities = this.find(query);
        int success = 0;
        int fail = 0;
        List<MatterDatumEntity> addEntities = new ArrayList<>();

        for (DatumLibraryEntity library : entities) {
            MatterDatumEntity datum = updateOrSave(library, matterId, context);
            //SiteMatterEntity siteMatterEntity = updateOrSave(matterEntity, siteId, context);
            if (!ObjectUtils.isEmpty(datum)) {
                addEntities.add(datum);
                success++;
            } else {
                fail++;
            }
        }
        if (!ObjectUtils.isEmpty(addEntities)) {
            matterDatumService.save(addEntities, context);
        }
        String msg = "当前加入材料已存在！";
        if(CollectionUtils.isEmpty(entities)){
            msg = "没有可以添加的数据！";
        }
        if (libraryIdList.size() == 1) {
            if (success > 0) {
                msg = "加入材料成功！";
            }
        } else if (libraryIdList.size() > 1) {
            if (success > 0 && fail == 0) {
                msg = String.format("加入材料成功%d条!", success);
            } else if (success > 0 && fail > 0) {
                msg = String.format("加入材料成功%d条，重复加入材料%d条！", success, fail);
            } else if (success == 0 && fail > 0) {
                msg = String.format("重复加入材料%d条！", fail);
            }
        }
        return Rest.ok(msg);
    }

    private MatterDatumEntity updateOrSave(DatumLibraryEntity item, Long matterId, Context context) {
        if(item.getDatumId()==null){
            item.setDatumId(-1l);
        }
        MatterApplyEntity matterApplyEntity = matterApplyService.get(matterId);
        if(matterApplyEntity==null){
            return  null;
        }
        MatterDatumQuery query = new MatterDatumQuery();
        query.setMatterId(matterId);
        query.setFullName(item.getFullName());
        MatterDatumEntity matterDatumEntity = matterDatumService.selectOne(query);
        if (ObjectUtils.isEmpty(matterDatumEntity)) {
            MatterDatumEntity datumEntity = BeanUtil.covert(item,MatterDatumEntity.class);
            datumEntity.setCreateTime(new Date());
            if(context!=null&&context.getUser()!=null) {
                datumEntity.setCreateUserId(context.getUser().getId());
            }
            datumEntity.setSuggest(0);
            datumEntity.setFillSum(0);
            datumEntity.setMatterId(matterId);
            datumEntity.setMatterCode(matterApplyEntity.getMatterCode());
            return datumEntity;
        }
        return null;
    }
}