package com.mortals.xhx.module.matter.service.impl;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.text.StrSplitter;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.deepoove.poi.XWPFTemplate;
import com.deepoove.poi.config.Configure;
import com.deepoove.poi.config.ConfigureBuilder;
import com.deepoove.poi.template.MetaTemplate;
import com.deepoove.poi.util.RegexUtils;
import com.mortals.xhx.common.code.ComponentEnum;
import com.mortals.xhx.common.formdesign.*;
import com.mortals.xhx.common.pdu.gen.component.ComponentCons;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.common.utils.WordUtil;
import com.mortals.xhx.module.matter.service.MatterApplyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.matter.dao.MatterDatumFileDao;
import com.mortals.xhx.module.matter.model.MatterDatumFileEntity;
import com.mortals.xhx.module.matter.service.MatterDatumFileService;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

/**
* MatterDatumFileService
* 材料附件业务 service实现
*
* @author zxfei
* @date 2023-04-07
*/
@Service("matterDatumFileService")
public class MatterDatumFileServiceImpl extends AbstractCRUDServiceImpl<MatterDatumFileDao, MatterDatumFileEntity, Long> implements MatterDatumFileService {

    @Autowired
    private MatterApplyService matterApplyService;

    @Value("${upload.path}")
    private String filePath;

    @Value("${upload.url:http://192.168.0.98:17216/cpm/file/commonupload?prePath=/file/uploadfile}")
    private String uploadUrl;

    @Value("${qrcode.url:http://rhpt.scjg.chengdu.gov.cn:8091/adap/spjy/process/generateQrCode.do?dto.applyId=}")
    private String qrcode;

    public static String word[] = {"doc", "dot", "wps", "wpt", "docx", "dotx", "docm", "dotm"};
    public static String imgs[] = {"jpg", "png", "jpeg", "gif"};
    public static String pdf[] = {"pdf"};

    @Override
    protected void saveAfter(MatterDatumFileEntity entity, Context context) throws AppException {
        super.saveAfter(entity,context);
        //matterApplyService.addDatumCount(entity.getMatterId(),1);
    }

    @Override
    protected void removeBefore(Long[] ids, Context context) throws AppException {
//        for(Long id:ids){
//            MatterDatumFileEntity entity = this.get(id);
//            if(entity!=null){
//                matterApplyService.addDatumCount(entity.getMatterId(),-1);
//            }
//        }
    }

    @Override
    protected void saveBefore(MatterDatumFileEntity entity, Context context) throws AppException {
        super.saveBefore(entity,context);
        if(entity.getUselType()==2 && StringUtils.isNotEmpty(entity.getTemplatePath())){
            //entity.setFormContent(parseDocxToJson(entity.getTemplateUrl()));
            parseDocxToJson(entity);

        }
        if(StringUtils.isNotEmpty(entity.getSamplePath())){
            String rootPath = this.filePath.endsWith("/") ? this.filePath : this.filePath + "/";
            String prePath = "file/preview/";
            String newName = genPreviewPath(rootPath, prePath,  entity.getSamplePath());
            entity.setPreviewUrl(prePath+newName);
        }
    }

    @Override
    protected void updateBefore(MatterDatumFileEntity entity, Context context) throws AppException {
        super.updateBefore(entity,context);
        if(entity.getUselType()==2 && StringUtils.isNotEmpty(entity.getTemplatePath())){
            //entity.setFormContent(parseDocxToJson(entity.getTemplateUrl()));
            parseDocxToJson(entity);
        }
        if(StringUtils.isNotEmpty(entity.getSamplePath())){
            String rootPath = this.filePath.endsWith("/") ? this.filePath : this.filePath + "/";
            String prePath = "file/preview/";
            String newName = genPreviewPath(rootPath, prePath,  entity.getSamplePath());
            entity.setPreviewUrl(prePath+newName);
        }
    }

    private void parseDocxToJson(MatterDatumFileEntity entity) {
        String rootPath = this.filePath.endsWith("/") ? this.filePath : this.filePath + "/";
        String filepath = rootPath + entity.getTemplatePath();
        ConfigureBuilder builder = Configure.builder();

        builder.setValidErrorHandler(new Configure.DiscardHandler());
        builder.useDefaultEL(false);
        builder.buildGrammerRegex(RegexUtils.createGeneral("{{", "}}"));
        //builder.buildGramer("[","]");
        XWPFTemplate template = XWPFTemplate.compile(filepath, builder.build());
        FormDesignRoot root = new FormDesignRoot();
        FormDesignConfig config = new FormDesignConfig();
        config.initAttribute();
        root.setConfig(config);
        List<ListItem> collect = new ArrayList<>();
        HashSet<String> hs = new HashSet<>(); //去除重复标签

        for (MetaTemplate item : template.getElementTemplates()) {
            if(hs.contains(item.variable())){
                continue;
            }else {
                hs.add(item.variable());
            }
            //识别简单输入
            String val = StrUtil.strip(item.variable(), "{{", "}}");

            List<String> keys = StrSplitter.split(val, "_", true, true);
            //切分分隔符后动态 创建组件  i_1_姓名（第一个代表类型，第二个如果是多个累加，第三个显示label）
            if (keys.size() > 2) {
                String label = keys.get(2);
                String type = keys.get(0);
                ComponentCons cons = new ComponentCons();
                cons.setLabel(label);
                cons.setVal(val);
                cons.setEl(item.variable());
                cons.setUploadFileUrl(uploadUrl);

                if (type.equalsIgnoreCase(ComponentEnum.DYNAMIC_TABLE.getValue())) {
                    HashSet<String> dhs = new HashSet<>(); //去除重复标签
                    List<TableColItem> colList = new ArrayList<>();
                    //表格 结构化绑定数据
                    ConfigureBuilder builderTable = Configure.builder();
                    builderTable.setValidErrorHandler(new Configure.DiscardHandler());
                    builderTable.useDefaultEL(false);
                    builderTable.buildGramer("[", "]");
                    XWPFTemplate templateTable = XWPFTemplate.compile(filepath, builderTable.build());

                    for (MetaTemplate col : templateTable.getElementTemplates()) {
                        if(dhs.contains(col.variable())){
                            continue;
                        }else {
                            dhs.add(col.variable());
                        }
                        String colVal = StrUtil.strip(col.variable(), "[", "]");
                        if (!StrUtil.startWith(colVal, label)) {
                            continue;
                        }
                        List<String> colKeys = StrSplitter.split(colVal, "_", true, true);
                        //提取当前table中的列元素
                        if (colKeys.size() > 3) {
                            String colLabel = colKeys.get(3);
                            String colType = colKeys.get(1);
                            TableColItem tableColItem = new TableColItem();
                            tableColItem.setLabel(colLabel);
                            tableColItem.setColType(colType);
                            tableColItem.setVal(colVal);
                            colList.add(tableColItem);
                            //System.out.println("列元素" + col.variable());
                        }
                    }
                    cons.setColList(colList);
                    DesignComponent designComponent = DesignComponent.createType(type);
                    ListItem listItem = designComponent.buildDefaultComponent(cons);
                    collect.add(listItem);
                    continue;
                }
                DesignComponent designComponent = DesignComponent.createType(type);
                ListItem listItem = designComponent.buildDefaultComponent(cons);
                if(type.equals(ComponentEnum.QRCODE.getValue())){
                    listItem.setValue(qrcode);
                }
                collect.add(listItem);
            }
        }
        root.setList(collect);
        entity.setFormContent(JSON.toJSONString(root));
    }


    private String genPreviewPath(String rootPath, String prePath, String tempPath) {
        //生成样表预览图片
        String samplePath = rootPath + tempPath;
        String filePath = rootPath + prePath;
        File pathDir = new File(filePath);
        if (!pathDir.exists()) {
            pathDir.mkdirs();
        }
        String newName = RandomUtil.randomNumbers(12) + ".jpg";
        String filePathAll = filePath + newName;
        //判断文件类型是否为doc pdf jpg png 等
        String extName = FileUtil.getSuffix(samplePath);
        if (this.isExsitArry(extName, word)) {
            WordUtil.convertWordToJPEG(samplePath, filePathAll);
        } else if (this.isExsitArry(extName, pdf)) {
            WordUtil.pdfToImages(samplePath, filePathAll);
        } else if (this.isExsitArry(extName, imgs)) {
            try {
                com.mortals.framework.util.FileUtil.copyFile(samplePath, filePathAll);
            } catch (FileNotFoundException e) {
                throw new RuntimeException(e);
            }
        }
        return newName;
    }

    public boolean isExsitArry(String chex, String arry[]) {
        for (String ex : arry) {
            if (chex.equalsIgnoreCase(ex)) {
                return true;
            }
        }
        return false;
    }
}