package com.mortals.xhx.module.matter.service.impl;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.common.utils.ImageBase64;
import lombok.Getter;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.matter.dao.UserMatterDetailsDao;
import com.mortals.xhx.module.matter.model.UserMatterDetailsEntity;
import com.mortals.xhx.module.matter.service.UserMatterDetailsService;

import java.io.File;
import java.util.Date;

/**
* UserMatterDetailsService
* 用户申报明细 service实现
*
* @author zxfei
* @date 2023-04-10
*/
@Service("userMatterDetailsService")
public class UserMatterDetailsServiceImpl extends AbstractCRUDServiceImpl<UserMatterDetailsDao, UserMatterDetailsEntity, Long> implements UserMatterDetailsService {

    @Value("${upload.path}")
    @Getter
    private String filePath;

    @Override
    protected void saveBefore(UserMatterDetailsEntity entity, Context context) throws AppException {
        this.validData(entity, context);
        if(StringUtils.isNotEmpty(entity.getImageBase64())){
            doSaveImageBase64(entity);
        }
    }

    private void doSaveImageBase64(UserMatterDetailsEntity entity){
        String base64 = String.valueOf(entity.getImageBase64());
        base64 = base64.replaceAll("data:image/png;base64,","");
        if(StringUtils.isEmpty(base64)){
            throw new AppException("图片不能为空");
        }
        String imageName = new Date().getTime() + ".png";
        String imagePath = "/file/uploadfile/"+imageName;

        String filePath = this.filePath.endsWith("/") ? this.filePath : this.filePath + "/" + imagePath;
        File pathDir = new File(this.filePath.endsWith("/") ? this.filePath : this.filePath + "/file/uploadfile");
        if (!pathDir.exists()) {
            pathDir.mkdirs();
        }
        try{
            ImageBase64.convertImg(base64.trim(),filePath);
            entity.setPreviewUrl(imagePath);
        }catch (Exception e){
            log.error("base64图片转换异常",e.fillInStackTrace());
            entity.setPreviewUrl("");
        }
    }
}