package com.mortals.xhx.module.matter.web;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.matter.model.DatumLibraryEntity;
import com.mortals.xhx.module.matter.model.vo.MatterApplyGroupVo;
import com.mortals.xhx.module.matter.service.UserMatterApplyService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.matter.model.MatterApplyEntity;
import com.mortals.xhx.module.matter.service.MatterApplyService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
*
* 申报事项
*
* @author zxfei
* @date 2023-04-07
*/
@RestController
@RequestMapping("matter/apply")
public class MatterApplyController extends BaseCRUDJsonBodyMappingController<MatterApplyService,MatterApplyEntity,Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private UserMatterApplyService userMatterApplyService;

    public MatterApplyController(){
        super.setModuleDesc( "申报事项");
    }

    @Override
    protected void doListBefore(MatterApplyEntity query, Map<String, Object> model, Context context) throws AppException {
        Map<String,String> orderMap = new HashMap<>();
        orderMap.put("datumCount","DESC");
        orderMap.put("reportCount","DESC");
        query.setOrderCols(orderMap);
        super.doListBefore(query,model,context);
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterApply","source"));

        super.init(model, context);
    }

    /**
     * 增加申报次数
     * @param id
     * @return
     */
    @RequestMapping(value = {"addReport"},method = {RequestMethod.POST, RequestMethod.GET})
    @UnAuth
    public String addReport(Long id) {
        Map<String, Object> model = new HashMap();
        if (id == null) {
            return this.createFailJsonResp("请选择待查看" + this.getModuleDesc() + "信息");
        } else {
            JSONObject ret = new JSONObject();
            String busiDesc = "查看" + this.getModuleDesc();
            Context context = this.getContext();
            try {
                MatterApplyEntity entity = this.service.get(id, context);
                if (entity == null) {
                    throw new Exception(busiDesc + "，不存在或已被删除");
                }
                service.addReportCount(id);
                model.put("message_info","操作成功");
                model.putAll(model);
                this.recordSysLog(this.request, busiDesc + " 【成功】");
            } catch (Exception var8) {
                this.doException(this.request, busiDesc, model, var8);
                Object msg = model.get("message_info");
                return this.createFailJsonResp(msg == null ? "系统异常" : msg.toString());
            }

            this.init(model, context);
            ret.put("data", model);
            ret.put("code", 1);
            ret.put("msg", model.remove("message_info"));
            return ret.toJSONString();
        }
    }

    @PostMapping({"groupList"})
    @UnAuth
    public Rest<Object> groupList(@RequestBody MatterApplyEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "分组查询" + this.getModuleDesc();

        int code;
        try {
            PageInfo pageInfo = this.buildPageInfo(query);
            Result<MatterApplyGroupVo> result = null;
            if(query.getGroupType()==1) {
                result = this.getService().findDeptGroup(query, pageInfo, context);
            }else {
                result = this.getService().findThemeGroup(query, pageInfo, context);
                if(CollectionUtils.isNotEmpty(result.getList())){
                    for(MatterApplyGroupVo vo:result.getList()){
                        if(StringUtils.isEmpty(vo.getThemeName())){
                            vo.setThemeName("无主题");
                        }
                    }
                }
            }
            model.put("data", result.getList());
            model.put("pageInfo", result.getPageInfo());
            model.put("allCount",userMatterApplyService.getAllCount());
            model.put("todayCount",userMatterApplyService.getTodayCount());
            this.parsePageInfo(model, result.getPageInfo());
            code = 1;
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }
}