package com.mortals.xhx.module.matter.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.site.SiteMatterPdu;
import com.mortals.xhx.feign.site.ISiteMatterFeign;
import com.mortals.xhx.module.matter.service.MatterApplyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("site/matter")
public class SiteMatterController extends BaseJsonBodyController {

    @Autowired
    private ISiteMatterFeign siteMatterFeign;
    @Autowired
    private MatterApplyService matterApplyService;

    @PostMapping({"list"})
    @UnAuth
    public Rest<Object> list(@RequestBody SiteMatterPdu query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询站点事项列表";

        int code;
        try {
            Rest<RespData<List<SiteMatterPdu>>> result = siteMatterFeign.list(query);
            code = result.getCode();
            if(code > 0) {
                model.put("data", result.getData().getData());
                model.put("pageInfo", result.getData().getPageInfo());
                model.put("dict", result.getData().getDict());
            }

            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }


        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 添加事项到申报事项
     */
    @PostMapping(value = "addToAssist")
    public String addToAssist(@RequestBody Map<String, Object> map) {
        JSONObject jsonObject = new JSONObject();
        Map<String, Object> model = new HashMap<String, Object>();
        String siteMatterIds = (String) map.get("siteMatterIds");
        try {
            Rest<String> rest = matterApplyService.addToAssist(siteMatterIds, getContext());
            jsonObject.put(KEY_RESULT_MSG, rest.getMsg());
            jsonObject.put(KEY_RESULT_DATA, model);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            this.recordSysLog(this.request, rest.getMsg());
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }
}
