package com.mortals.xhx.module.sst.service.impl;
import com.mortals.framework.common.Rest;
import com.mortals.framework.util.DataUtil;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.RespData;
import com.mortals.xhx.common.pdu.app.AppPdu;
import com.mortals.xhx.common.pdu.app.DeviceBlackappPdu;
import com.mortals.xhx.common.utils.StringUtils;
import com.mortals.xhx.feign.app.IAppFeign;
import com.mortals.xhx.module.apps.model.AppsInfoEntity;
import com.mortals.xhx.module.apps.service.AppsInfoService;
import com.mortals.xhx.module.sst.model.SstAppsQuery;
import org.apache.commons.collections4.CollectionUtils;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.xhx.module.sst.dao.SstAppsDao;
import com.mortals.xhx.module.sst.model.SstAppsEntity;
import com.mortals.xhx.module.sst.service.SstAppsService;

import java.util.*;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
* SstAppsService
* 应用编排 service实现
*
* @author zxfei
* @date 2022-12-21
*/
@Service("sstAppsService")
public class SstAppsServiceImpl extends AbstractCRUDServiceImpl<SstAppsDao, SstAppsEntity, Long> implements SstAppsService {

    @Autowired
    private AppsInfoService appsInfoService;
    @Autowired
    private IAppFeign appFeign;

    @Override
    public Map<String, Object> getAppsBySiteId(Long siteId) throws AppException {
        if(siteId == null){
            throw new AppException("站点id不能为空");
        }
        AppsInfoEntity appsInfoQuery = new AppsInfoEntity();
        appsInfoQuery.setSiteId(siteId);
        List<AppsInfoEntity> allApps = appsInfoService.find(appsInfoQuery);
        SstAppsEntity query = new SstAppsEntity();
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("basicSort","DESC");
        query.setOrderCols(orderCols);
        query.setSiteId(siteId);
        List<SstAppsEntity> appsEntities = this.find(query);
        Map<String, Object> siteApp = new HashMap<>();
        siteApp.put("allApps", allApps);
        if(CollectionUtils.isNotEmpty(appsEntities)){
            List<SstAppsEntity> showApps = new ArrayList<>();
            List<SstAppsEntity> hotApps = new ArrayList<>();
            for(SstAppsEntity sstAppsEntity:appsEntities){
                if(sstAppsEntity.getShowBasic()==1){
                    showApps.add(sstAppsEntity);
                }
                if(sstAppsEntity.getShowHot()==1){
                    hotApps.add(sstAppsEntity);
                }
            }
            siteApp.put("showApps", showApps);
            siteApp.put("hotApps", hotApps);
        }else {
            siteApp.put("showApps", Collections.emptyList());
            siteApp.put("hotApps", Collections.emptyList());
        }
        return siteApp;
    }

    @Override
    public void settingSave(Long siteId, String showAppIds, String hotAppIds,Context context) throws AppException {
        Map<Long,SstAppsEntity> sstAppIds = new HashMap<>();

        if(StringUtils.isNotEmpty(showAppIds)){
            String appIds[] = showAppIds.split(",");
            int sort = 99;
            for(String id:appIds){
                Long appId = DataUtil.converStr2Long(id,0l);
                AppsInfoEntity appsInfoEntity = appsInfoService.get(appId);
                if(appsInfoEntity!=null) {
                    SstAppsEntity sstAppsEntity = new SstAppsEntity();
                    sstAppsEntity.setSiteId(siteId);
                    sstAppsEntity.setAppId(appId);
                    sstAppsEntity.setName(appsInfoEntity.getName());
                    sstAppsEntity.setDescribe(appsInfoEntity.getDescribe());
                    sstAppsEntity.setUrl(appsInfoEntity.getUrl());
                    sstAppsEntity.setShowBasic(1);
                    sstAppsEntity.setBasicSort(sort);
                    sstAppsEntity.setShowHot(0);
                    sstAppsEntity.setHotSort(0);
                    if(context!=null){
                        sstAppsEntity.setCreateUserId(context.getUser().getId());
                        sstAppsEntity.setCreateTime(new Date());
                    }
                    sstAppIds.put(appId, sstAppsEntity);
                    sort--;
                }
            }
        }
        if(StringUtils.isNotEmpty(hotAppIds)){
            String appIds[] = hotAppIds.split(",");
            int sort = 99;
            for(String id:appIds){
                Long appId = DataUtil.converStr2Long(id,0l);
                if(sstAppIds.containsKey(appId)){
                    sstAppIds.get(appId).setShowHot(1);
                    sstAppIds.get(appId).setHotSort(sort);
                    sort--;
                }else {
                    AppsInfoEntity appsInfoEntity = appsInfoService.get(appId);
                    if (appsInfoEntity != null) {
                        SstAppsEntity sstAppsEntity = new SstAppsEntity();
                        sstAppsEntity.setSiteId(siteId);
                        sstAppsEntity.setAppId(appId);
                        sstAppsEntity.setName(appsInfoEntity.getName());
                        sstAppsEntity.setDescribe(appsInfoEntity.getDescribe());
                        sstAppsEntity.setUrl(appsInfoEntity.getUrl());
                        sstAppsEntity.setShowBasic(0);
                        sstAppsEntity.setBasicSort(0);
                        sstAppsEntity.setShowHot(1);
                        sstAppsEntity.setHotSort(sort);
                        if (context != null) {
                            sstAppsEntity.setCreateUserId(context.getUser().getId());
                            sstAppsEntity.setCreateTime(new Date());
                        }
                        sstAppIds.put(appId, sstAppsEntity);
                        sort--;
                    }
                }
            }
        }
        Map<String,Object> condition = new HashMap<>();
        condition.put("siteId",siteId);
        this.dao.delete(condition);
        if(sstAppIds.size()>0){
            List<SstAppsEntity> list = sstAppIds.values().stream().collect(Collectors.toList());
            this.dao.insertBatch(list);
        }
    }

    @Override
    public Map<String, Object> getAppListBySite(String deviceCode,Long siteId,String host,String appName) {
        SstAppsEntity query = new SstAppsEntity();
        Map<String,String> orderCols = new HashMap<>();
        orderCols.put("clickSum","DESC");
        orderCols.put("basicSort","DESC");
        query.setOrderCols(orderCols);
        query.setSiteId(siteId);
        List<SstAppsEntity> appsEntities = this.find(query);
        Map<Long,Long> black = new HashMap<>();
        if(StringUtils.isNotEmpty(deviceCode)){
            DeviceBlackappPdu blackappPdu = new DeviceBlackappPdu();
            blackappPdu.setSiteId(siteId);
            blackappPdu.setDeviceCode(deviceCode);
            Rest<RespData<List<DeviceBlackappPdu>>> rest = appFeign.blackappList(blackappPdu);
            if (rest.getCode().equals(YesNoEnum.YES.getValue())) {
                List<AppsInfoEntity> appsInfoEntities = new ArrayList<>();
                for(DeviceBlackappPdu pdu:rest.getData().getData()){
                    black.put(pdu.getAppId(),pdu.getAppId());
                }

            }
        }

        AppsInfoEntity appsInfoQuery = new AppsInfoEntity();
        appsInfoQuery.setSiteId(siteId);
        appsInfoQuery.setName(appName);
        List<AppsInfoEntity> allApps = appsInfoService.find(appsInfoQuery);
        for(AppsInfoEntity appsInfoEntity:allApps){
            if(com.mortals.framework.util.StringUtils.isNotEmpty(host)) {
                appsInfoEntity.setCustUrl(host + "/" + appsInfoEntity.getCustUrl());
            }
        }
        Map<Long,AppsInfoEntity> appInfoMap = allApps.stream().collect(Collectors.toMap(AppsInfoEntity::getId, Function.identity()));
        Map<String, Object> siteApp = new HashMap<>();
        siteApp.put("allApps", allApps);
        if(CollectionUtils.isNotEmpty(appsEntities)){
            List<AppsInfoEntity> showApps = new ArrayList<>();
            List<AppsInfoEntity> hotApps = new ArrayList<>();
            for(SstAppsEntity sstAppsEntity:appsEntities){
                if(black.containsKey(sstAppsEntity.getAppId())){
                    continue;
                }
                if(!appInfoMap.containsKey(sstAppsEntity.getAppId())){
                    continue;
                }
                appInfoMap.get(sstAppsEntity.getAppId()).setClickSum(sstAppsEntity.getClickSum());
                appInfoMap.get(sstAppsEntity.getAppId()).setSort(sstAppsEntity.getBasicSort());
                if(sstAppsEntity.getShowBasic()==1){
                    showApps.add(appInfoMap.get(sstAppsEntity.getAppId()));
                }
                if(sstAppsEntity.getShowHot()==1){
                    hotApps.add(appInfoMap.get(sstAppsEntity.getAppId()));
                }
            }
            siteApp.put("showApps", showApps);
            siteApp.put("hotApps", hotApps);
        }else {
            siteApp.put("showApps", Collections.emptyList());
            siteApp.put("hotApps", Collections.emptyList());
        }
        return siteApp;
    }

    @Override
    public void forbidden(Long appId, Long userId) {
        Map<String,Object> condition = new HashMap<>();
        condition.put("appId",appId);
        this.dao.delete(condition);
    }

    @Override
    public void clickCountAdd(Long appId,Long siteId) {
        SstAppsEntity sstAppsEntity = this.selectOne(new SstAppsQuery().appId(appId).siteId(siteId));
        if(sstAppsEntity!=null){
            Map<String,Object> condition = new HashMap<>();
            condition.put("id",sstAppsEntity.getId());
            Map<String,Object> data = new HashMap<>();
            data.put("clickSumIncrement",1);
            this.dao.update(data,condition);
        }
    }
}